'use strict'

import addMapEntry from './addMapEntry.js'
import arrayReduce from './arrayReduce.js'
import mapToArray  from './mapToArray.js'

/** Used to compose bitmasks for cloning. */
const CLONE_DEEP_FLAG = 1;

/**
 * Creates a clone of `map`.
 *
 * @private
 * @param {Object} map The map to clone.
 * @param {boolean} [isDeep] Specify a deep clone.
 * @param {Function} cloneFunc The function to clone values.
 * @returns {Object} Returns the cloned map.
 */
const cloneMap = ( map, isDeep, cloneFunc ) =>
{
    const array = isDeep ? cloneFunc(mapToArray(map), CLONE_DEEP_FLAG) : mapToArray(map) ;
    return arrayReduce( array , addMapEntry , new map.constructor() ) ;
}

export default cloneMap ;