'use strict'

import addSetEntry from './addSetEntry.js'
import arrayReduce from './arrayReduce.js'
import setToArray  from './setToArray.js'

/** Used to compose bitmasks for cloning. */
const CLONE_DEEP_FLAG = 1 ;

/**
 * Creates a clone of `set`.
 * @private
 * @param {Object} set The set to clone.
 * @param {boolean} [isDeep] Specify a deep clone.
 * @param {Function} cloneFunc The function to clone values.
 * @returns {Object} Returns the cloned set.
 */
const cloneSet = ( set, isDeep, cloneFunc ) =>
{
    const array = isDeep ? cloneFunc( setToArray(set) , CLONE_DEEP_FLAG ) : setToArray( set ) ;
    return arrayReduce( array , addSetEntry , new set.constructor() ) ;
}

export default cloneSet ;