'use strict'

import arrayEach from './_/arrayEach.js'
import baseEach from './_/baseEach.js'

/**
 * Iterates over elements of `collection` and invokes `iteratee` for each element.
 * The iteratee is invoked with three arguments: (value, index|key, collection).
 * Iteratee functions may exit iteration early by explicitly returning `false`.
 *
 * **Note:** As with other "Collections" methods, objects with a "length" property are iterated like arrays. To avoid this behavior use `forIn` or `forOwn` for object iteration.
 *
 * @since 1.0.37
 * @alias each
 * @category Collection
 * @param {Array|Object} collection The collection to iterate over.
 * @param {Function} iteratee The function invoked per iteration.
 * @returns {Array|Object} Returns `collection`.
 * @example
 *
 * forEach( [1, 2] , value => console.log( value ) ) ;
 *
 * forEach( { 'a': 1, 'b': 2 } , ( value , key ) => console.log(key) ) ;
 */
const forEach = ( collection , iteratee ) =>
{
    const func = Array.isArray( collection ) ? arrayEach : baseEach ;
    return func( collection , iteratee ) ;
}

export default forEach ;